@@ -37,7 +37,7 @@ from .typing import (
     MenuItemsSettingsNode,
     MenuItemsSettingsStructure,
     MenuItemsSettingsUpdate,
-    MenuItemsSettingsValueData,
+    MenuItemsSettingsUpdateValueData,
     Strings,
     StringsRequest,
     SystemType,
@@ -111,6 +111,7 @@ def decode_xtv_json(text: str):
         data = json.loads(text)
     except json.decoder.JSONDecodeError:
         LOG.debug("Invalid json received, trying adjusted version")
+        text = text.replace('"channelList": { "id": "version", "" }', '"channelList": { "id": "all", "version": "" }')
         text = text.replace("{,", "{")
         text = text.replace(",}", "}")
         while (p := text.find(",,")) >= 0:
@@ -1454,8 +1455,8 @@ class PhilipsTV(object):
         if self.json_feature_supported("menuitems", "Setup_Menu") or force:
             return await self.postReq("menuitems/settings/update", cast(dict, post))
 
-    async def postMenuItemsSettingsUpdateData(self, value: Dict[int, MenuItemsSettingsValueData], force=False):
-        post = {
+    async def postMenuItemsSettingsUpdateData(self, value: Dict[int, MenuItemsSettingsUpdateValueData], force=False):
+        post: MenuItemsSettingsUpdate = {
             "values": [
                 {
                     "value": {
@@ -1466,7 +1467,7 @@ class PhilipsTV(object):
                 for node_id, data in value.items()
             ]
         }
-        return await self.postMenuItemsSettingsUpdate(cast(MenuItemsSettingsUpdate, post), force=force)
+        return await self.postMenuItemsSettingsUpdate(post, force=force)
         
 
     async def notifyChange(self, timeout=TIMEOUT_NOTIFYREAD):
